@@ -23,11 +23,16 @@ import msgpack
 from socket import gaierror
 import time
 from typing import Iterable, Optional, Union
+import sys
+import os
+
+from opentracing import Format
 
 from gs_quant.api.risk import RiskApi
 from gs_quant.risk import RiskRequest
 from gs_quant.session import GsSession
 from gs_quant.target.risk import OptimizationRequest
+from gs_quant.tracing import Tracer
 
 _logger = logging.getLogger(__name__)
 
@@ -37,7 +42,6 @@ class WebsocketUnavailable(Exception):
 
 
 class GsRiskApi(RiskApi):
-
     USE_MSGPACK = True
     POLL_FOR_BATCH_RESULTS = False
 
@@ -59,6 +63,7 @@ class GsRiskApi(RiskApi):
     def _exec(cls, request: Union[RiskRequest, Iterable[RiskRequest]]) -> Union[Iterable, dict]:
         use_msgpack = cls.USE_MSGPACK and not isinstance(request, RiskRequest)
         headers = {'Content-Type': 'application/x-msgpack'} if use_msgpack else {}
+        Tracer.inject(Format.HTTP_HEADERS, headers)
         result, request_id = GsSession.current._post(cls.__url(request),
                                                      request,
                                                      request_headers=headers,
@@ -76,7 +81,8 @@ class GsRiskApi(RiskApi):
         return '/risk/calculate{}'.format('/bulk' if is_bulk else '')
 
     @classmethod
-    async def get_results(cls, responses: asyncio.Queue, results: asyncio.Queue, timeout: Optional[int] = None):
+    async def get_results(cls, responses: asyncio.Queue, results: asyncio.Queue,
+                          timeout: Optional[int] = None) -> Optional[str]:
         if cls.POLL_FOR_BATCH_RESULTS:
             return await cls.__get_results_poll(responses, results, timeout=timeout)
         else:
@@ -122,9 +128,10 @@ class GsRiskApi(RiskApi):
                     elif 'result' in result:
                         results.put_nowait((pending_requests.pop(result['requestId']), result['result']))
             except Exception as e:
-                _logger.error(f'Fatal error: {e}')
+                error_str = f'Fatal error polling for results: {e}'
+                _logger.error(error_str)
                 cls.shutdown_queue_listener(results)
-                return
+                return error_str
 
     @classmethod
     async def __get_results_ws(cls, responses: asyncio.Queue, results: asyncio.Queue, timeout: Optional[int] = None):
@@ -144,7 +151,7 @@ class GsRiskApi(RiskApi):
                 while pending_requests or not all_requests_dispatched:
                     # Continue while we have pending or un-dispatched requests
 
-                    request_listener = asyncio.ensure_future(cls.drain_queue_async(responses))\
+                    request_listener = asyncio.ensure_future(cls.drain_queue_async(responses)) \
                         if not all_requests_dispatched else None
                     result_listener = asyncio.ensure_future(ws.recv())
                     listeners = tuple(filter(None, (request_listener, result_listener)))
@@ -156,9 +163,12 @@ class GsRiskApi(RiskApi):
 
                     if result_listener in complete:
                         # New results have been received
-
-                        request_id, status_result_str = result_listener.result().split(';', 1)
-                        status, result_str = status_result_str[0], status_result_str[1:]
+                        try:
+                            request_id, status_result_str = result_listener.result().split(';', 1)
+                            status, result_str = status_result_str[0], status_result_str[1:]
+                        except Exception as ee:
+                            status = 'E'
+                            result_str = str(ee)
 
                         if status == 'E':
                             # An error
@@ -167,7 +177,7 @@ class GsRiskApi(RiskApi):
                             # Unpack the result
 
                             try:
-                                result = msgpack.unpackb(base64.b64decode(result_str), raw=False)\
+                                result = msgpack.unpackb(base64.b64decode(result_str), raw=False) \
                                     if cls.USE_MSGPACK else json.loads(result_str)
                             except Exception as ee:
                                 result = ee
@@ -200,7 +210,9 @@ class GsRiskApi(RiskApi):
                         else:
                             request_listener.cancel()
             except Exception as ee:
-                ret = str(ee)
+                exc_type, exc_obj, exc_tb = sys.exc_info()
+                fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
+                ret = f'{exc_type} {fname} ln:{exc_tb.tb_lineno}' + str(ee)
 
             return ret
 
@@ -235,8 +247,9 @@ class GsRiskApi(RiskApi):
                 attempts = max_attempts
 
         if error != '':
-            _logger.error(f'Fatal error: {error}')
+            _logger.error(f'Fatal error with websocket: {error}')
             cls.shutdown_queue_listener(results)
+            return error
 
     @classmethod
     def create_pretrade_execution_optimization(cls, request: OptimizationRequest) -> str:
