@@ -28,6 +28,7 @@ from gs_quant.base import RiskKey, Sentinel
 from gs_quant.risk import ErrorValue, RiskRequest
 from gs_quant.risk.result_handlers import result_handlers
 from gs_quant.session import GsSession
+from gs_quant.tracing import Tracer
 
 _logger = logging.getLogger(__name__)
 
@@ -38,7 +39,8 @@ class RiskApi(metaclass=ABCMeta):
 
     @classmethod
     @abstractmethod
-    async def get_results(cls, responses: asyncio.Queue, results: asyncio.Queue, timeout: Optional[int] = None):
+    async def get_results(cls, responses: asyncio.Queue, results: asyncio.Queue,
+                          timeout: Optional[int] = None) -> Optional[str]:
         ...
 
     @classmethod
@@ -110,7 +112,7 @@ class RiskApi(metaclass=ABCMeta):
     def shutdown_queue_listener(cls,
                                 q: Union[queue.Queue, asyncio.Queue],
                                 loop: Optional[asyncio.AbstractEventLoop] = None):
-        if loop:
+        if loop and not loop.is_closed():
             loop.call_soon_threadsafe(q.put_nowait, cls.__SHUTDOWN_SENTINEL)
         else:
             q.put_nowait(cls.__SHUTDOWN_SENTINEL)
@@ -121,7 +123,8 @@ class RiskApi(metaclass=ABCMeta):
             results: queue.Queue,
             max_concurrent: int,
             progress_bar: Optional[tqdm] = None,
-            timeout: Optional[int] = None):
+            timeout: Optional[int] = None,
+            span: Optional[str] = None):
         def _process_results(completed: list):
             chunk_results = tuple(itertools.chain.from_iterable(cls._handle_results(request, result).items()
                                                                 for request, result in completed))
@@ -138,7 +141,10 @@ class RiskApi(metaclass=ABCMeta):
                              responses: asyncio.Queue,
                              raw_results: asyncio.Queue,
                              session: GsSession,
-                             loop: asyncio.AbstractEventLoop):
+                             loop: asyncio.AbstractEventLoop,
+                             active_span):
+            if active_span:
+                Tracer.get_instance().scope_manager.activate(active_span, finish_on_close=False)
             with session:
                 shutdown = False
                 while not shutdown:
@@ -158,7 +164,7 @@ class RiskApi(metaclass=ABCMeta):
                     # If we are in async mode, indicate to the result subscriber that there are no more requests
                     cls.shutdown_queue_listener(responses, loop=loop)
 
-        async def run_async():
+        async def run_async(current_span):
             def num_risk_jobs(request: RiskRequest):
                 # size of calculation job
                 return len(request.pricing_and_market_data_as_of) * len(request.positions)
@@ -178,7 +184,7 @@ class RiskApi(metaclass=ABCMeta):
             # The requests library (which we use for dispatching) is not async, so we need a thread for concurrency
             Thread(daemon=True,
                    target=execute_requests,
-                   args=(outstanding_requests, responses, raw_results, GsSession.current, loop)).start()
+                   args=(outstanding_requests, responses, raw_results, GsSession.current, loop, current_span)).start()
 
             if is_async:
                 # If async we need a task to handle result subscription
@@ -233,7 +239,10 @@ class RiskApi(metaclass=ABCMeta):
             cls.shutdown_queue_listener(outstanding_requests)
 
             if results_handler:
-                await results_handler
+                results_error = await results_handler
+                if results_error:
+                    # Raise an exception so that pending results can be filled with an error
+                    raise RuntimeError(f'Fatal Error subscribing to results: {results_error}')
 
             if progress_bar:
                 progress_bar.close()
@@ -244,14 +253,8 @@ class RiskApi(metaclass=ABCMeta):
 
             cls.shutdown_queue_listener(results)
 
-            if result_thread is not None:
-                cls.shutdown_queue_listener(unprocessed_results)
-                result_thread.join()
-
-            cls.shutdown_queue_listener(results)
-
         if sys.version_info >= (3, 7):
-            asyncio.run(run_async())
+            asyncio.run(run_async(span))
         else:
             try:
                 existing_event_loop = asyncio.get_event_loop()
@@ -265,7 +268,7 @@ class RiskApi(metaclass=ABCMeta):
                 asyncio.set_event_loop(main_loop)
 
             try:
-                main_loop.run_until_complete(run_async())
+                main_loop.run_until_complete(run_async(span))
             except Exception:
                 if not use_existing:
                     main_loop.stop()
