@@ -14,12 +14,14 @@ specific language governing permissions and limitations
 under the License.
 """
 import datetime as dt
-from dateutil.parser import isoparse
 import re
-from typing import Optional, Union
+from typing import Optional, Union, Iterable, Dict, Tuple
+
+from dataclasses_json import config
+from dateutil.parser import isoparse
 
 __valid_date_formats = ('%Y-%m-%d',  # '2020-07-28'
-                        '%d%b%y',    # '28Jul20'
+                        '%d%b%y',  # '28Jul20'
                         '%d-%b-%y',  # '28-Jul-20'
                         '%d/%m/%Y')  # '28/07/2020
 
@@ -37,6 +39,34 @@ def decode_optional_date(value: Optional[str]) -> Optional[dt.date]:
     raise ValueError(f'Cannot convert {value} to date')
 
 
+def decode_date_tuple(blob: Tuple[str]):
+    return tuple(decode_optional_date(s) for s in blob) if isinstance(blob, (tuple, list)) else None
+
+
+def optional_from_isodatetime(datetime: str):
+    return dt.datetime.fromisoformat(datetime.replace('Z', '')) if datetime is not None else None
+
+
+def optional_to_isodatetime(datetime: Optional[dt.datetime]):
+    return f'{dt.datetime.isoformat(datetime, timespec="seconds")}Z' if datetime is not None else None
+
+
+optional_datetime_config = config(encoder=optional_to_isodatetime, decoder=optional_from_isodatetime)
+optional_date_config = config(encoder=encode_date_or_str, decoder=decode_optional_date)
+
+
+def decode_dict_date_key(value):
+    return {dt.date.fromisoformat(d): v for d, v in value.items()} if value is not None else None
+
+
+def decode_dict_date_value(value):
+    return {k: dt.date.fromisoformat(d) for k, d in value.items()} if value is not None else None
+
+
+def decode_datetime_tuple(blob: Tuple[str]):
+    return tuple(optional_from_isodatetime(s) for s in blob) if isinstance(blob, (tuple, list)) else None
+
+
 def decode_date_or_str(value: Union[dt.date, float, str]) -> Optional[Union[dt.date, str]]:
     if value is None or isinstance(value, dt.date):
         return value
@@ -111,5 +141,25 @@ def decode_instrument(value: Optional[dict]):
     return Instrument.from_dict(value) if value else None
 
 
+def decode_quote_report(value: Optional[dict]):
+    from gs_quant.quote_reports.core import quote_report_from_dict
+    return quote_report_from_dict(value) if value else None
+
+
+def decode_quote_reports(value: Optional[Iterable[Dict]]):
+    from gs_quant.quote_reports.core import quote_reports_from_dicts
+    return quote_reports_from_dicts(value) if value else None
+
+
+def decode_custom_comment(value: Optional[dict]):
+    from gs_quant.quote_reports.core import custom_comment_from_dict
+    return custom_comment_from_dict(value) if value else None
+
+
+def decode_custom_comments(value: Optional[Iterable[Dict]]):
+    from gs_quant.quote_reports.core import custom_comments_from_dicts
+    return custom_comments_from_dicts(value) if value else None
+
+
 def encode_dictable(o):
     return o if o is None else o.to_dict()
