@@ -106,7 +106,7 @@ class Index(Asset, PositionedEntity):
     def get_fundamentals(self,
                          start: dt.date = DateLimit.LOW_LIMIT.value,
                          end: dt.date = dt.date.today(),
-                         period: DataMeasure = DataMeasure.ONE_YEAR.value,
+                         period: Optional[DataMeasure] = None,
                          direction: DataMeasure = DataMeasure.FORWARD.value,
                          metrics: List[DataMeasure] = DataMeasure.list_fundamentals()) -> pd.DataFrame:
         """
@@ -115,7 +115,7 @@ class Index(Asset, PositionedEntity):
         :param start: start date (default is 1 January, 1970)
         :param end: end date (default is today)
         :param period: period for the relevant metric.  Can be one of ONE_YEAR('1y'), TWO_YEARS('2y'), \
-            THREE_YEARS('3y') (default is 1y)
+            THREE_YEARS('3y') (default is all periods)
         :param direction: direction of the outlook period. Can be one of 'forward' or 'trailing' (default is forward)
         :param metrics: list of fundamentals metrics. (default is all)
         :return: dataframe with fundamentals information
@@ -135,7 +135,9 @@ class Index(Asset, PositionedEntity):
         >>> index.get_fundamentals(metrics=[DataMeasure.DIVIDEND_YIELD])
         """
         if self.__is_sts_index():
-            where = dict(assetId=self.id, period=period, periodDirection=direction, metric=metrics)
+            where = dict(assetId=self.id, periodDirection=direction, metric=metrics)
+            if period:
+                where["period"] = period
             query = DataQuery(where=where, start_date=start, end_date=end)
             response = GsDataApi.query_data(query=query, dataset_id=IndicesDatasets.STS_FUNDAMENTALS.value)
             return pd.DataFrame(response)
@@ -258,8 +260,7 @@ class Index(Asset, PositionedEntity):
 
         if self.__is_sts_index():
             if price_type == [PriceType.INDICATIVE_CLOSE_PRICE]:
-                response = self.__query_indicative_levels_dataset(start=start, end=end)
-                indicative_level = pd.DataFrame(response)
+                indicative_level = self.__query_indicative_levels_dataset(start=start, end=end)
                 indicative_level.drop(['updateTime', 'assetId'], axis=1, inplace=True)
                 indicative_level = indicative_level.astype({'date': 'datetime64[ns]'})
                 prices['date'] = indicative_level['date']
@@ -267,8 +268,7 @@ class Index(Asset, PositionedEntity):
                 return prices
 
             official_level = super().get_close_prices(start=start, end=end).to_frame('closePrice')
-            response = self.__query_indicative_levels_dataset(start=start, end=end)
-            indicative_level = pd.DataFrame(response)
+            indicative_level = self.__query_indicative_levels_dataset(start=start, end=end)
 
             official_level.reset_index(inplace=True)
             indicative_level.drop(['updateTime', 'assetId'], axis=1, inplace=True)
@@ -531,7 +531,7 @@ class Index(Asset, PositionedEntity):
             return True
         return False
 
-    def __query_indicative_levels_dataset(self, start=None, end=None):
+    def __query_indicative_levels_dataset(self, start=None, end=None) -> pd.DataFrame:
 
         where = dict(assetId=self.id)
         if start is None:
@@ -540,7 +540,13 @@ class Index(Asset, PositionedEntity):
             query = DataQuery(where=where, start_date=start, end_date=end)
 
         response = GsDataApi.query_data(query=query, dataset_id=IndicesDatasets.STS_INDICATIVE_LEVELS.value)
-        return response
+        indicative_level = pd.DataFrame(response)
+        if (len(indicative_level) == 0):
+            indicative_level['date'] = ''
+            indicative_level['assetId'] = ''
+            indicative_level['updateTime'] = ''
+            indicative_level['indicativeClosePrice'] = ''
+        return indicative_level
 
     @staticmethod
     def __get_gs_asset(identifier: str) -> GsAsset:
