@@ -82,6 +82,7 @@ class PortfolioManager(PositionedEntity):
                  portfolio_id: str):
         """
         Initialize a Portfolio Manager
+
         :param portfolio_id: Portfolio ID
         """
         self.__portfolio_id = portfolio_id
@@ -96,6 +97,11 @@ class PortfolioManager(PositionedEntity):
         self.__portfolio_id = value
 
     def get_performance_report(self) -> PerformanceReport:
+        """
+        Get performance report associated with a portfolio
+
+        :return: returns the PerformanceReport associated with portfolio if one exists
+        """
         reports = GsReportApi.get_reports(limit=100,
                                           position_source_type='Portfolio',
                                           position_source_id=self.id,
@@ -107,24 +113,117 @@ class PortfolioManager(PositionedEntity):
     def schedule_reports(self,
                          start_date: dt.date = None,
                          end_date: dt.date = None,
-                         backcast: bool = False):
-        GsPortfolioApi.schedule_reports(self.__portfolio_id, start_date, end_date, backcast=backcast)
+                         backcast: bool = False,
+                         months_per_batch: int = None):
+        """
+        Schedule all reports associated with a portfolio. If months_per_batch is passed and reports are historical, then
+        schedule them in batches of bathc_period months. Backcasted reported can't be batched.
+
+        :param start_date: start date of report job (optional)
+        :param end_date: end date of report job (optional)
+        :param backcast: true if reports should be backcasted; defaults to false
+        :param months_per_batch: batch size of historical report job schedules in number of months; defaults to false
+        if set, historical reports are scheduled in batches of size less than or equal to the given number of months
+
+        **Examples**
+
+        >>> pm = PortfolioManager("PORTFOLIO ID")
+        >>> pm.schedule_reports(backcast=False)
+
+        for a portfolio having hisotry greater than 1 yr, use months_per_batch to schedule reports in batches of
+        6 months
+        >>> pm = PortfolioManager("PORTFOLIO ID")
+        >>> pm.schedule_reports(backcast=False, months_per_batch=6)
+        """
+        if months_per_batch is None or backcast:
+            if backcast:
+                print('Batching of schedule reports is only supported for historical reports. '
+                      'Backcasted reports will be scheduled for the full date range')
+            GsPortfolioApi.schedule_reports(self.__portfolio_id, start_date, end_date, backcast=backcast)
+        else:
+            # Process input
+            if months_per_batch <= 0:
+                raise MqValueError(f'Invalid input, months_per_batch {months_per_batch} should be greater than 0')
+
+            if end_date is None or start_date is None:
+                hints = self.get_schedule_dates(backcast=backcast)
+                start_date = hints[0] if start_date is None else start_date
+                end_date = hints[1] if end_date is None else end_date
+
+            if start_date >= end_date:
+                raise MqValueError(f'Invalid input, start date {start_date} should be before end date {end_date}')
+
+            # Validate input date range against position dates
+            position_dates = self.get_position_dates()
+            position_dates = [p for p in position_dates if end_date >= p >= start_date]
+
+            if len(position_dates) == 0:
+                raise MqValueError('Portfolio does not have any positions in the given date range')
+
+            if start_date not in position_dates:
+                # There should be positions on the start date for historical reports
+                raise MqError('Cannot schedule historical report because the first set of positions within the '
+                              f'scheduling date range need to be on this date {start_date}')
+            else:
+                # preparation for the first batch
+                position_dates.remove(start_date)
+
+            if end_date not in position_dates:
+                # make sure to process the last batch
+                position_dates.append(end_date)
+
+            # Create batches using sliding window
+            batch_boundaries = [start_date]
+            prev_date = start_date
+            for i, d in enumerate(position_dates):
+                current_batch = d - prev_date
+                if current_batch.days > months_per_batch * 30 and i > 0:
+                    # split the current window at the previous date
+                    prev_date = position_dates[i - 1]
+                    batch_boundaries.append(prev_date)
+
+            batch_boundaries.append(end_date)
+
+            # Schedule reports in batches
+            print(f'Scheduling reports from {start_date} to {end_date} in {len(batch_boundaries) - 1} batches')
+
+            for i in range(len(batch_boundaries) - 1):
+                print(f'Scheduling for {batch_boundaries[i]} to {batch_boundaries[i+1]}')
+                GsPortfolioApi.schedule_reports(self.__portfolio_id,
+                                                batch_boundaries[i],
+                                                batch_boundaries[i + 1],
+                                                backcast=backcast)
+                if i > 0 and i % 10 == 0:
+                    sleep(6)
 
     def run_reports(self,
                     start_date: dt.date = None,
                     end_date: dt.date = None,
                     backcast: bool = False,
-                    is_async: bool = True) -> List[Union[pd.DataFrame, ReportJobFuture]]:
+                    is_async: bool = True,
+                    months_per_batch: int = None) -> List[Union[pd.DataFrame, ReportJobFuture]]:
         """
         Run all reports associated with a portfolio
+
         :param start_date: start date of report job
         :param end_date: end date of report job
         :param backcast: true if reports should be backcasted; defaults to false
         :param is_async: true if reports should run asynchronously; defaults to true
+        :param months_per_batch: batch size of historical report job schedules in number of months; defaults to false
+        if set, historical reports are scheduled in batches of size less than or equal to the given number of months
         :return: if is_async is true, returns a list of ReportJobFuture objects; if is_async is false, returns a list
         of dataframe objects containing report results for all portfolio results
+
+        **Examples**
+
+        >>> pm = PortfolioManager("PORTFOLIO ID")
+        >>> report_results = pm.run_reports(backcast=True)
+
+        for longer hisotry, use months_per_batch to schedule reports in batches of 6 months
+        >>> pm = PortfolioManager("PORTFOLIO ID")
+        >>> pm.schedule_reports(backcast=False, months_per_batch=6)
         """
-        self.schedule_reports(start_date, end_date, backcast)
+        self.schedule_reports(start_date, end_date, backcast, months_per_batch)
         reports = self.get_reports()
         report_futures = [report.get_most_recent_job() for report in reports]
         if is_async:
@@ -143,7 +242,23 @@ class PortfolioManager(PositionedEntity):
                          entitlements: Entitlements):
         """
         Set the entitlements of a portfolio
+
         :param entitlements: Entitlements object
+
+        **Examples**
+
+        >>> portfolio_admin_emails = ['LIST OF ADMIN EMAILS']
+        >>> portfolio_viewer_emails = ['LIST OF VIEWER EMAILS']
+        >>> admin_entitlements = EntitlementBlock(users=User.get_many(emails=portfolio_admin_emails))
+        >>> view_entitlements = EntitlementBlock(users=User.get_many(emails=portfolio_viewer_emails))
+        >>>
+        >>> entitlements = Entitlements(
+        >>>    view=view_entitlements,
+        >>>    admin=admin_entitlements
+        >>> )
+        >>>
+        >>> pm = PortfolioManager("PORTFOLIO ID")
+        >>> pm.set_entitlements(entitlements)
         """
         entitlements_as_target = entitlements.to_target()
         portfolio_as_target = GsPortfolioApi.get_portfolio(self.__portfolio_id)
@@ -154,6 +269,7 @@ class PortfolioManager(PositionedEntity):
                            backcast: bool = False) -> List[dt.date]:
         """
         Get recommended start and end dates for a portfolio report scheduling job
+
         :param backcast: true if reports should be backcasted
         :return: a list of two dates, the first is the suggested start date and the second is the suggested end date
         """
@@ -162,7 +278,8 @@ class PortfolioManager(PositionedEntity):
     def get_aum_source(self) -> RiskAumSource:
         """
         Get portfolio AUM Source
-        :return: AUM Source
+
+        :return: aum source
         """
         portfolio = GsPortfolioApi.get_portfolio(self.portfolio_id)
         return portfolio.aum_source if portfolio.aum_source is not None else RiskAumSource.Long
@@ -171,8 +288,9 @@ class PortfolioManager(PositionedEntity):
                        aum_source: RiskAumSource):
         """
         Set portfolio AUM Source
+
         :param aum_source: aum source for portfolio
-        :return:
+        :return: aum source
         """
         portfolio = GsPortfolioApi.get_portfolio(self.portfolio_id)
         portfolio.aum_source = aum_source
@@ -183,6 +301,7 @@ class PortfolioManager(PositionedEntity):
                        end_date: dt.date = None) -> List[CustomAUMDataPoint]:
         """
         Get AUM data for portfolio
+
         :param start_date: start date
         :param end_date: end date
         :return: list of AUM data between the specified range
@@ -191,13 +310,16 @@ class PortfolioManager(PositionedEntity):
         return [CustomAUMDataPoint(date=dt.datetime.strptime(data['date'], '%Y-%m-%d'),
                                    aum=data['aum']) for data in aum_data]
 
-    def get_aum(self, start_date: dt.date, end_date: dt.date):
+    def get_aum(self,
+                start_date: dt.date,
+                end_date: dt.date):
         """
         Get AUM data for portfolio
+
         :param start_date: start date
         :param end_date: end date
         :return: dictionary of dates with corresponding AUM values
-         """
+        """
         aum_source = self.get_aum_source()
         if aum_source == RiskAumSource.Custom_AUM:
             aum = self.get_custom_aum(start_date=start_date, end_date=end_date)
@@ -220,10 +342,9 @@ class PortfolioManager(PositionedEntity):
                           clear_existing_data: bool = None):
         """
         Add AUM data for portfolio
+
         :param aum_data: list of AUM data to upload
-        :param clear_existing_data: delete all previously uploaded AUM data for the portfolio
-        (defaults to false)
-        :return:
+        :param clear_existing_data: delete all previously uploaded AUM data for the portfolio (defaults to false)
         """
         formatted_aum_data = [{'date': data.date.strftime('%Y-%m-%d'), 'aum': data.aum} for data in aum_data]
         GsPortfolioApi.upload_custom_aum(self.portfolio_id, formatted_aum_data, clear_existing_data)
@@ -234,6 +355,7 @@ class PortfolioManager(PositionedEntity):
                              currency: Currency = None) -> pd.DataFrame:
         """
         Get PnL Contribution of your portfolio broken down by constituents
+
         :param start_date: optional start date
         :param end_date: optional end date
         :param currency: optional currency; defaults to your portfolio's currency
@@ -253,6 +375,7 @@ class PortfolioManager(PositionedEntity):
                                  ) -> Union[Dict, pd.DataFrame]:
         """
         Get portfolio and asset exposure to macro factors
+
         :param macro_risk_model: the macro risk model
         :param date: date for which to get exposure
         :param factors: macro factors to get portfolio and asset exposure for.
@@ -343,6 +466,7 @@ class PortfolioManager(PositionedEntity):
 
         """
         Get portfolio and asset exposure to macro factors or macro factor categories
+
         :param model: the macro risk model
         :param date: date for which to get exposure
         :param factor_type: whether to get exposure to factor categories or factors.
@@ -352,6 +476,20 @@ class PortfolioManager(PositionedEntity):
         :param get_factors_by_name: whether to identify factors by their name or identifier
         :param return_format: whether to return a dict or a pandas dataframe
         :return: a Pandas Dataframe or a Dict of portfolio exposure to macro factors
+
+        **Examples**
+
+        >>> model = MacroRiskModel.get(\"MODEL\")
+        >>> pm = PortfolioManager("PORTFOLIO ID")
+        >>> exposure_dataframe = pm.get_macro_exposure(
+        >>>     model=model,
+        >>>     date=dt.date(2022, 1, 1),
+        >>>     factor_type=FactorType.Factor
+        >>> ).sort_values(
+        >>>     by=[\"Total Factor Exposure\"],
+        >>>     axis=1,
+        >>>     ascending=False
+        >>> )
         """
         performance_report = self.get_performance_report()
 
