@@ -15,7 +15,7 @@ under the License.
 """
 import calendar
 import datetime
-import functools
+import datetime as dt
 import json
 import logging
 import threading
@@ -23,17 +23,19 @@ import time
 from abc import ABCMeta, abstractmethod
 from collections import defaultdict
 from copy import deepcopy
-from enum import auto
+from enum import auto, Enum
 from functools import partial
-from typing import Dict, Tuple, Generator, Iterable
+from typing import Tuple, Generator, Iterable, Optional, Dict, List, Union
 
 import backoff
 import cachetools
+import pandas as pd
 import pytz
 from dateutil.relativedelta import relativedelta
+from pydash import get
 
-from gs_quant.api.gs.assets import GsAsset, AssetParameters, \
-    AssetType as GsAssetType, Currency, GsIdType
+from gs_quant.api.gs.assets import GsAsset, AssetParameters, AssetType as GsAssetType, Currency, GsIdType, GsAssetApi
+from gs_quant.api.gs.data import GsDataApi
 from gs_quant.api.utils import ThreadPoolManager
 from gs_quant.base import get_enum_value
 from gs_quant.common import DateLimit
@@ -45,7 +47,10 @@ from gs_quant.entities.entity import Entity, EntityIdentifier, EntityType, Posit
 from gs_quant.errors import MqValueError, MqTypeError, MqRequestError
 from gs_quant.json_encoder import JSONEncoder
 from gs_quant.markets import PricingContext
-from gs_quant.markets.indices_utils import *
+from gs_quant.markets.indices_utils import BasketType, IndicesDatasets
+from gs_quant.session import GsSession
+from gs_quant.target.common import AssetClass
+from gs_quant.target.data import DataQuery
 
 _logger = logging.getLogger(__name__)
 
@@ -313,7 +318,12 @@ class Asset(Entity, metaclass=ABCMeta):
         :func:`get_asset`
         """
         if not as_of:
-            as_of = PricingContext.current.pricing_date
+            current = PricingContext.current
+            if not current.is_entered:
+                with current:
+                    as_of = current.pricing_date
+            else:
+                as_of = current.pricing_date
 
             if isinstance(as_of, dt.datetime):
                 as_of = as_of.date()
@@ -574,8 +584,14 @@ class SecMasterAsset(Asset):
         marquee_id = self.get_identifier(SecurityIdentifier.ASSET_ID)
         self.__id = marquee_id  # Updates Marquee Id in case it changes from context change
         if marquee_id is None:
+            current = PricingContext.current
+            if not current.is_entered:
+                with current:
+                    current_pricing_date = current.pricing_date
+            else:
+                current_pricing_date = current.pricing_date
             raise MqValueError(
-                f"Current SecMasterAsset does not have a Marquee Id as of {PricingContext.current.pricing_date}. "
+                f"Current SecMasterAsset does not have a Marquee Id as of {current_pricing_date}. "
                 f"Perhaps asset did not exist at that time, or is a not an exchange-level asset.")
         return marquee_id
 
@@ -598,7 +614,12 @@ class SecMasterAsset(Asset):
             self.__load_identifiers()
         # Retrieve from cached identifiers
         if as_of is None:
-            as_of = PricingContext.current.pricing_date
+            current = PricingContext.current
+            if not current.is_entered:
+                with current:
+                    as_of = current.pricing_date
+            else:
+                as_of = current.pricing_date
         identifiers = dict()
         for id_type in SecurityIdentifier:
             id_history = self.__cached_identifiers.get(id_type.value)
@@ -1248,6 +1269,23 @@ class XccySwapMTM(Asset):
         return AssetType.XccySwapMTM
 
 
+class MutualFund(Asset):
+    """MutualFund
+
+    Represents a mutual fund asset.
+    """
+
+    def __init__(self,
+                 id_: str,
+                 name: str,
+                 asset_class: AssetClass,
+                 entity: Optional[Dict] = None):
+        Asset.__init__(self, id_, asset_class, name, entity=entity)
+
+    def get_type(self) -> AssetType:
+        return AssetType.MUTUAL_FUND
+
+
 class SecurityMasterSource(Enum):
     ASSET_SERVICE = auto()
     SECURITY_MASTER = auto()
@@ -1391,6 +1429,9 @@ class SecurityMaster:
         if asset_type == GsAssetType.XccySwapMTM.value:
             return XccySwapMTM(gs_asset.id, gs_asset.name, entity=asset_entity)
 
+        if asset_type == GsAssetType.Mutual_Fund.value:
+            return MutualFund(gs_asset.id, gs_asset.name, gs_asset.asset_class, entity=asset_entity)
+
         raise TypeError(f'unsupported asset type {asset_type}')
 
     @classmethod
@@ -1419,7 +1460,7 @@ class SecurityMaster:
                   as_of: Union[dt.date, dt.datetime] = None,
                   exchange_code: ExchangeCode = None,
                   asset_type: AssetType = None,
-                  sort_by_rank: bool = False,
+                  sort_by_rank: bool = True,
                   fields: Optional[List[str]] = None) -> Asset:
         """
         Get an asset by identifier and identifier type
@@ -1429,7 +1470,7 @@ class SecurityMaster:
         :param exchange_code: exchange code
         :param asset_type: asset type
         :param as_of: As of date for query
-        :param sort_by_rank: whether to sort assets by rank.
+        :param sort_by_rank: whether to sort assets by rank. This flag is ignored when using SecMasterContext
         :param fields: asset fields to return
         :return: Asset object or None
 
@@ -1461,12 +1502,17 @@ class SecurityMaster:
         if cls._source == SecurityMasterSource.SECURITY_MASTER:
             if not isinstance(id_type, SecurityIdentifier):
                 raise MqTypeError('expected a security identifier')
-            if exchange_code or asset_type or sort_by_rank:
+            if exchange_code or asset_type:
                 raise NotImplementedError('argument not implemented for Security Master (supported in Asset Service)')
             return cls._get_security_master_asset(id_value, id_type, as_of=as_of, fields=fields)
 
         if not as_of:
-            as_of = PricingContext.current.pricing_date
+            current = PricingContext.current
+            if not current.is_entered:
+                with current:
+                    as_of = current.pricing_date
+            else:
+                as_of = current.pricing_date
 
         if isinstance(as_of, dt.date):
             as_of = dt.datetime.combine(as_of, dt.time(0, 0), pytz.utc)
@@ -1622,7 +1668,7 @@ class SecurityMaster:
 
         as_of = as_of or datetime.datetime.now()
         if types is not None:
-            p = functools.partial(cls.asset_type_to_str, class_)
+            p = partial(cls.asset_type_to_str, class_)
             types = set(map(p, types))
 
         params = {
