@@ -13,30 +13,32 @@ KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 """
-
-from abc import abstractmethod
-import backoff
-import certifi
-from configparser import ConfigParser
-from enum import Enum, auto, unique
 import inspect
 import itertools
 import json
-import msgpack
+import logging
 import os
+import ssl
+from abc import abstractmethod
+from configparser import ConfigParser
+from enum import Enum, auto, unique
+from typing import Optional, Union, Iterable
+
+import backoff
+import certifi
+import msgpack
 import pandas as pd
 import requests
 import requests.adapters
 import requests.cookies
-import ssl
-from typing import Optional, Union, Iterable
-
 from gs_quant import version as APP_VERSION
 from gs_quant.base import Base
 from gs_quant.context_base import ContextBase
 from gs_quant.errors import MqError, MqRequestError, MqAuthenticationError, MqUninitialisedError
 from gs_quant.json_encoder import JSONEncoder, encode_default
 
+logger = logging.getLogger(__name__)
+
 API_VERSION = 'v1'
 DEFAULT_APPLICATION = 'gs-quant'
 DEFAULT_TIMEOUT = 65
@@ -132,7 +134,9 @@ class GsSession(ContextBase):
     @staticmethod
     def __ssl_context() -> ssl.SSLContext:
         if GsSession.__ssl_ctx is None:
-            GsSession.__ssl_ctx = ssl.create_default_context(purpose=ssl.Purpose.CLIENT_AUTH)
+            GsSession.__ssl_ctx = ssl.SSLContext(ssl.PROTOCOL_TLS_CLIENT)
+            GsSession.__ssl_ctx.check_hostname = False
+            GsSession.__ssl_ctx.verify_mode = 0
             GsSession.__ssl_ctx.load_default_certs()
             GsSession.__ssl_ctx.load_verify_locations(certifi.where())
 
@@ -197,18 +201,20 @@ class GsSession(ContextBase):
 
         response = self._session.request(method, url, **kwargs)
         request_id = response.headers.get('x-dash-requestid')
+        logger.debug('Handling response for [Request ID]: %s [Method]: %s [URL]: %s', request_id, method, url)
 
         if response.status_code == 401:
             # Expired token or other authorization issue
             if not try_auth:
-                raise MqRequestError(response.status_code, response.text, context='{} {}'.format(method, url))
+                raise MqRequestError(response.status_code, response.text,
+                                     context=f'{request_id}: {method} {url}')
             self._authenticate()
             return self.__request(method, path, payload=payload, cls=cls,
                                   include_version=include_version, return_request_id=return_request_id,
                                   use_body=use_body, try_auth=False)
         elif not 199 < response.status_code < 300:
             raise MqRequestError(response.status_code, response.text,
-                                 context=f'{response.headers.get("")}: {method} {url}')
+                                 context=f'{request_id}: {method} {url}')
         elif 'Content-Type' in response.headers:
             if 'application/x-msgpack' in response.headers['Content-Type']:
                 res = msgpack.unpackb(response.content, raw=False)
