@@ -398,6 +398,7 @@ class AssetGetRequestPathSchema(Base):
     fields: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
     order_by: Optional[Tuple[Union[DictBase, str], ...]] = field(default=None, metadata=field_metadata)
     next_rebalance_date: Optional[Tuple[datetime.date, ...]] = field(default=None, metadata=field_metadata)
+    asset_classifications_digital_asset_class: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
     sectors: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
     ticker: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
     valoren: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
@@ -424,11 +425,13 @@ class AssetGetRequestPathSchema(Base):
     last_updated_by_id: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
     expiration_date: Optional[Tuple[datetime.date, ...]] = field(default=None, metadata=field_metadata)
     asset_parameters_index: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
+    asset_classifications_digital_asset_sector: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
     display_id: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
     isin: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
     asset_parameters_strike_type: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
     created_by_id: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
     asset_parameters_cap_floor: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
+    asset_classifications_underliers_asset_class: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
     last_updated_since: Optional[Tuple[datetime.datetime, ...]] = field(default=None, metadata=field_metadata)
     option_type: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
     exchange: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
@@ -462,6 +465,7 @@ class AssetGetRequestPathSchema(Base):
     type_: Optional[Tuple[DictBase, ...]] = field(default=None, metadata=config(field_name='type', exclude=exclude_none))
     asset_parameters_index2_tenor: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
     rating_standard_and_poors: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
+    asset_classifications_digital_asset_subsector: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
     asset_parameters_fee_currency: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
     asset_parameters_receiver_spread: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
 
