@@ -60,22 +60,48 @@ class SecMasterAssetType(EnumBase, Enum):
     Equity_WRT = 'Equity WRT'
     Savings_Plan = 'Savings Plan'
     Equity_Index = 'Equity Index'
-    Municipal_Bonds = 'Municipal Bonds'
     Municipal_Bond = 'Municipal Bond'
     Corporate_Bond = 'Corporate Bond'
     Government_Bond = 'Government Bond'
     Agency_Bond = 'Agency Bond'
-    Currency = 'Currency'    
+    Currency = 'Currency'
+    Equity_Option = 'Equity Option'
+    Financial_index_future_ = 'Financial index future.'
+    Single_Stock_Future = 'Single Stock Future'
+    Pool = 'Pool'
+    Certificate_of_Deposit = 'Certificate of Deposit'
+    Debt_Structured_Note = 'Debt Structured Note'
+    Agency_CMO = 'Agency CMO'
+    Future_Option = 'Future Option'
+    Convertible_Bond = 'Convertible Bond'    
 
 
-class SecMasterSourceNames(EnumBase, Enum):    
+class SecMasterCorporateActionStatus(EnumBase, Enum):    
     
-    """Data source."""
+    """Status of corporate actions."""
 
-    Barra = 'Barra'
-    Refinitiv = 'Refinitiv'
-    Bloomberg = 'Bloomberg'
-    Goldman_Sachs = 'Goldman Sachs'    
+    Normal = 'Normal'
+    Completed = 'Completed'
+    Pending = 'Pending'
+    Deleted = 'Deleted'
+    Incomplete = 'Incomplete'
+    Missing_Adj_Factor = 'Missing Adj Factor'
+    Not_Quoted_By_Exchange = 'Not Quoted By Exchange'
+    Missing_Terms = 'Missing Terms'
+    Cancelled = 'Cancelled'
+    Lapsed = 'Lapsed'
+    Proposed = 'Proposed'
+    Withdrawn = 'Withdrawn'    
+
+
+class SecMasterCorporateActionType(EnumBase, Enum):    
+    
+    """Types of corporate actions."""
+
+    Cash_Dividend = 'Cash Dividend'
+    Merger = 'Merger'
+    Spinoff = 'Spinoff'
+    Split = 'Split'    
 
 
 @handle_camel_case_args
@@ -93,6 +119,18 @@ class SecMasterAuditFields(Base):
 SecMasterIdentifiers = Dict[str, str]
 
 
+@handle_camel_case_args
+@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass(unsafe_hash=True, repr=False)
+class SecMasterRecord(Base):
+    recordid: Optional[float] = field(default=None, metadata=field_metadata)
+    action_type: Optional[str] = field(default=None, metadata=field_metadata)
+    instrument_value: Optional[float] = field(default=None, metadata=field_metadata)
+    data_value: Optional[float] = field(default=None, metadata=field_metadata)
+    term_type: Optional[str] = field(default=None, metadata=field_metadata)
+    name: Optional[str] = field(default=None, metadata=name_metadata)
+
+
 @handle_camel_case_args
 @dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass(unsafe_hash=True, repr=False)
@@ -102,6 +140,9 @@ class SecMasterResourceCompany(Base):
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
 
+SecMasterSources = Dict[str, str]
+
+
 @handle_camel_case_args
 @dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass(unsafe_hash=True, repr=False)
@@ -132,6 +173,37 @@ class ExchangeGetRequestPathSchema(Base):
     offset_key: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
 
 
+@handle_camel_case_args
+@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass(unsafe_hash=True, repr=False)
+class SecMasterAssetSources(Base):
+    id_: Optional[str] = field(default=None, metadata=config(field_name='id', exclude=exclude_none))
+    asset_class: Optional[str] = field(default=None, metadata=field_metadata)
+    product: Optional[SecMasterSources] = field(default=None, metadata=field_metadata)
+    exchange: Optional[SecMasterSources] = field(default=None, metadata=field_metadata)
+    company: Optional[SecMasterSources] = field(default=None, metadata=field_metadata)
+    classifications: Optional[SecMasterSources] = field(default=None, metadata=field_metadata)
+    identifiers: Optional[SecMasterSources] = field(default=None, metadata=field_metadata)
+    name: Optional[str] = field(default=None, metadata=name_metadata)
+
+
+@handle_camel_case_args
+@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass(unsafe_hash=True, repr=False)
+class SecMasterCorporateAction(Base):
+    actionid: Optional[str] = field(default=None, metadata=field_metadata)
+    eventid: Optional[str] = field(default=None, metadata=field_metadata)
+    gsid: Optional[str] = field(default=None, metadata=field_metadata)
+    event_type: Optional[SecMasterCorporateActionType] = field(default=None, metadata=field_metadata)
+    announce_date: Optional[datetime.date] = field(default=None, metadata=field_metadata)
+    effective_date: Optional[datetime.date] = field(default=None, metadata=field_metadata)
+    multiplicative_adjust: Optional[float] = field(default=None, metadata=field_metadata)
+    additive_adjust: Optional[float] = field(default=None, metadata=field_metadata)
+    event_status: Optional[SecMasterCorporateActionStatus] = field(default=None, metadata=field_metadata)
+    records: Optional[Tuple[SecMasterRecord, ...]] = field(default=None, metadata=field_metadata)
+    name: Optional[str] = field(default=None, metadata=name_metadata)
+
+
 @handle_camel_case_args
 @dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass(unsafe_hash=True, repr=False)
@@ -145,6 +217,19 @@ class SecMasterExchange(SecMasterResponseMulti):
     identifiers: Optional[SecMasterIdentifiers] = field(default=None, metadata=field_metadata)
 
 
+@handle_camel_case_args
+@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass(unsafe_hash=True, repr=False)
+class SecMasterGetActionsRequestPathSchema(Base):
+    event_type: Optional[Tuple[SecMasterCorporateActionType, ...]] = field(default=None, metadata=field_metadata)
+    event_status: Optional[Tuple[SecMasterCorporateActionStatus, ...]] = field(default=None, metadata=field_metadata)
+    gsid: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
+    event_id: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
+    corp_action_id: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
+    effective_date: Optional[Tuple[datetime.date, ...]] = field(default=None, metadata=field_metadata)
+    name: Optional[str] = field(default=None, metadata=name_metadata)
+
+
 @handle_camel_case_args
 @dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass(unsafe_hash=True, repr=False)
@@ -185,9 +270,6 @@ class SecMasterResourceProduct(Base):
     identifiers: Optional[SecMasterIdentifiers] = field(default=None, metadata=field_metadata)
 
 
-SecMasterSources = Dict[str, SecMasterSourceNames]
-
-
 @handle_camel_case_args
 @dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass(unsafe_hash=True, repr=False)
@@ -201,38 +283,11 @@ class SecMasterTemporalProduct(SecMasterResponseMulti):
     primary_exchange_id: Optional[str] = field(default=None, metadata=field_metadata)
     type_: Optional[SecMasterAssetType] = field(default=None, metadata=config(field_name='type', exclude=exclude_none))
     subtype: Optional[str] = field(default=None, metadata=field_metadata)
-    source: Optional[SecMasterSourceNames] = field(default=None, metadata=field_metadata)
+    source: Optional[str] = field(default=None, metadata=field_metadata)
     flag: Optional[bool] = field(default=None, metadata=field_metadata)
     update_time: Optional[datetime.datetime] = field(default=None, metadata=field_metadata)
 
 
-@handle_camel_case_args
-@dataclass_json(letter_case=LetterCase.CAMEL)
-@dataclass(unsafe_hash=True, repr=False)
-class SecMasterAssetSources(Base):
-    id_: Optional[SecMasterSourceNames] = field(default=None, metadata=config(field_name='id', exclude=exclude_none))
-    asset_class: Optional[SecMasterSourceNames] = field(default=None, metadata=field_metadata)
-    product: Optional[SecMasterSources] = field(default=None, metadata=field_metadata)
-    exchange: Optional[SecMasterSources] = field(default=None, metadata=field_metadata)
-    company: Optional[SecMasterSources] = field(default=None, metadata=field_metadata)
-    classifications: Optional[SecMasterSources] = field(default=None, metadata=field_metadata)
-    identifiers: Optional[SecMasterSources] = field(default=None, metadata=field_metadata)
-    name: Optional[str] = field(default=None, metadata=name_metadata)
-
-
-@handle_camel_case_args
-@dataclass_json(letter_case=LetterCase.CAMEL)
-@dataclass(unsafe_hash=True, repr=False)
-class SecMasterResponseMulti(Base):
-    request_id: Optional[str] = field(default=None, metadata=field_metadata)
-    results: Optional[Tuple[SecMasterResponseMulti, ...]] = field(default=None, metadata=field_metadata)
-    total_results: Optional[float] = field(default=None, metadata=field_metadata)
-    offset_key: Optional[str] = field(default=None, metadata=field_metadata)
-    limit: Optional[int] = field(default=None, metadata=field_metadata)
-    offset: Optional[int] = field(default=None, metadata=field_metadata)
-    name: Optional[str] = field(default=None, metadata=name_metadata)
-
-
 @handle_camel_case_args
 @dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass(unsafe_hash=True, repr=False)
@@ -253,6 +308,29 @@ class SecMasterAsset(Base):
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
 
+@handle_camel_case_args
+@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass(unsafe_hash=True, repr=False)
+class SecMasterResponseActions(Base):
+    results: Optional[Tuple[SecMasterCorporateAction, ...]] = field(default=None, metadata=field_metadata)
+    total_results: Optional[float] = field(default=None, metadata=field_metadata)
+    offset_key: Optional[str] = field(default=None, metadata=field_metadata)
+    name: Optional[str] = field(default=None, metadata=name_metadata)
+
+
+@handle_camel_case_args
+@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass(unsafe_hash=True, repr=False)
+class SecMasterResponseMulti(Base):
+    request_id: Optional[str] = field(default=None, metadata=field_metadata)
+    results: Optional[Tuple[SecMasterResponseMulti, ...]] = field(default=None, metadata=field_metadata)
+    total_results: Optional[float] = field(default=None, metadata=field_metadata)
+    offset_key: Optional[str] = field(default=None, metadata=field_metadata)
+    limit: Optional[int] = field(default=None, metadata=field_metadata)
+    offset: Optional[int] = field(default=None, metadata=field_metadata)
+    name: Optional[str] = field(default=None, metadata=name_metadata)
+
+
 @handle_camel_case_args
 @dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass(unsafe_hash=True, repr=False)
