@@ -203,6 +203,8 @@ class WorkflowPosition(Base):
     original_workflow_id: Optional[str] = field(default=None, metadata=field_metadata)
     description: Optional[str] = field(default=None, metadata=field_metadata)
     entitlements: Optional[WorkflowEntitlements] = field(default=None, metadata=field_metadata)
+    is_read_only: Optional[bool] = field(default=None, metadata=field_metadata)
+    creator: Optional[str] = field(default=None, metadata=field_metadata)
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
 
