@@ -45,6 +45,7 @@ class ComponentType(EnumBase, Enum):
     rates = 'rates'
     relatedLinks = 'relatedLinks'
     research = 'research'
+    screener = 'screener'
     selector = 'selector'
     separator = 'separator'
     stackedBarChart = 'stackedBarChart'
@@ -295,6 +296,15 @@ class ResearchComponentParameters(Base):
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
 
+@handle_camel_case_args
+@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass(unsafe_hash=True, repr=False)
+class ScreenerComponentParameters(Base):
+    height: float = field(default=None, metadata=field_metadata)
+    tooltip: Optional[str] = field(default=None, metadata=field_metadata)
+    name: Optional[str] = field(default=None, metadata=name_metadata)
+
+
 @handle_camel_case_args
 @dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass(unsafe_hash=True, repr=False)
